@@ -26,6 +26,7 @@ int loadcfg(const char *cfgfile)
 		 {"UnitMode", 0, &cfg.unitmode, 0, 0},
 		 {"RateUnitMode", 0, &cfg.rateunitmode, 0, 0},
 		 {"OutputStyle", 0, &cfg.ostyle, 0, 0},
+		 {"EstimateBarVisible", 0, &cfg.estimatebarvisible, 0, 0},
 		 {"RateUnit", 0, &cfg.rateunit, 0, 0},
 		 {"DefaultDecimals", 0, &cfg.defaultdecimals, 0, 0},
 		 {"HourlyDecimals", 0, &cfg.hourlydecimals, 0, 0},
@@ -70,6 +71,14 @@ int loadcfg(const char *cfgfile)
 		 {"HourlyRate", 0, &cfg.hourlyrate, 0, 0},
 		 {"SummaryRate", 0, &cfg.summaryrate, 0, 0},
 		 {"TransparentBg", 0, &cfg.transbg, 0, 0},
+		 {"LargeFonts", 0, &cfg.largefonts, 0, 0},
+		 {"LineSpacingAdjustment", 0, &cfg.linespaceadjust, 0, 0},
+		 {"ImageScale", 0, &cfg.imagescale, 0, 0},
+		 {"5MinuteGraphResultCount", 0, &cfg.fivegresultcount, 0, 0},
+		 {"5MinuteGraphHeight", 0, &cfg.fivegheight, 0, 0},
+		 {"SummaryGraph", 0, &cfg.summarygraph, 0, 0},
+		 {"EstimateStyle", 0, &cfg.estimatestyle, 0, 0},
+		 {"BarColumnShowsRate", 0, &cfg.barshowsrate, 0, 0},
 		 {"CBackground", cfg.cbg, 0, 8, 0},
 		 {"CEdge", cfg.cedge, 0, 8, 0},
 		 {"CHeader", cfg.cheader, 0, 8, 0},
@@ -82,6 +91,7 @@ int loadcfg(const char *cfgfile)
 		 {"CRxD", cfg.crxd, 0, 8, 0},
 		 {"CTx", cfg.ctx, 0, 8, 0},
 		 {"CTxD", cfg.ctxd, 0, 8, 0},
+		 {"Experimental", 0, &cfg.experimental, 0, 0},
 		 {0, 0, 0, 0, 0}};
 
 	/* load default config */
@@ -176,6 +186,7 @@ void validatecfg(void)
 	validateint("UnitMode", &cfg.unitmode, UNITMODE, 0, 2);
 	validatebool("RateUnitMode", &cfg.rateunitmode, RATEUNITMODE);
 	validateint("OutputStyle", &cfg.ostyle, OSTYLE, 0, 3);
+	validatebool("EstimateBarVisible", &cfg.estimatebarvisible, ESTIMATEBARVISIBLE);
 	validateint("DefaultDecimals", &cfg.defaultdecimals, DEFAULTDECIMALS, 0, 2);
 	validateint("HourlyDecimals", &cfg.hourlydecimals, HOURLYDECIMALS, 0, 2);
 	validateint("HourlySectionStyle", &cfg.hourlystyle, HOURLYSTYLE, 0, 3);
@@ -195,6 +206,14 @@ void validatecfg(void)
 	validatebool("DatabaseWriteAheadLogging", &cfg.waldb, WALDB);
 	validateint("DatabaseSynchronous", &cfg.dbsynchronous, DBSYNCHRONOUS, -1, 3);
 	validatebool("TransparentBg", &cfg.transbg, TRANSBG);
+	validatebool("LargeFonts", &cfg.largefonts, LARGEFONTS);
+	validateint("LineSpacingAdjustment", &cfg.linespaceadjust, LINESPACEADJUST, -5, 10);
+	validateint("ImageScale", &cfg.imagescale, IMAGESCALE, 50, 500);
+	validateint("5MinuteGraphResultCount", &cfg.fivegresultcount, FIVEGRESULTCOUNT, FIVEGMINRESULTCOUNT, 2000);
+	validateint("5MinuteGraphHeight", &cfg.fivegheight, FIVEGHEIGHT, FIVEGMINHEIGHT, 2000);
+	validatebool("SummaryGraph", &cfg.summarygraph, SUMMARYGRAPH);
+	validateint("EstimateStyle", &cfg.estimatestyle, ESTIMATESTYLE, 0, 2);
+	validatebool("BarColumnShowsRate", &cfg.barshowsrate, BARSHOWSRATE);
 	validatebool("HourlyRate", &cfg.hourlyrate, HOURLYRATE);
 	validatebool("SummaryRate", &cfg.summaryrate, SUMMARYRATE);
 	validatebool("TrafficlessEntries", &cfg.trafficlessentries, TRAFFICLESSENTRIES);
@@ -212,6 +231,7 @@ void validatecfg(void)
 	validateint("TopDayEntries", &cfg.topdayentries, TOPDAYENTRIES, -1, -1);
 	validatebool("BandwidthDetection", &cfg.bwdetection, BWDETECT);
 	validateint("BandwidthDetectionInterval", &cfg.bwdetectioninterval, BWDETECTINTERVAL, 0, 30);
+	validatebool("Experimental", &cfg.experimental, 0);
 
 	if (cfg.dbdir[0] != '/') {
 		strncpy_nt(cfg.dbdir, DATABASEDIR, 512);
@@ -265,7 +285,7 @@ void validatecfg(void)
 	/* 1.02 is the same 2% safety buffer as used in processifinfo() in daemon.c */
 	/* noexit check results in warning being shown only when the daemon is started */
 	if (noexit && cfg.maxbw > 0) {
-		rolloversecs = (uint32_t)(MAX32 / (cfg.maxbw * 1024 * 1024 * (float)1.02 / 8));
+		rolloversecs = (uint32_t)((float)MAX32 / ((float)cfg.maxbw * 1024 * 1024 * (float)1.02 / 8));
 		if (rolloversecs <= (uint32_t)cfg.updateinterval) {
 			cfg.updateinterval = UPDATEINTERVAL;
 			if (rolloversecs <= (uint32_t)cfg.updateinterval) {
@@ -275,6 +295,20 @@ void validatecfg(void)
 			printe(PT_Config);
 		}
 	}
+
+	/* affects only image output */
+	if (cfg.barshowsrate && cfg.estimatebarvisible) {
+		cfg.estimatestyle = 0;
+		if (debug) {
+			printf("BarColumnShowsRate and EstimateBarVisible both enabled -> EstimateStyle set to 0\n");
+		}
+	}
+
+	if (cfg.fiveminutehours > 0 && cfg.fivegresultcount > cfg.fiveminutehours * 12) {
+		cfg.fivegresultcount = cfg.fiveminutehours * 12;
+		snprintf(errorstring, 1024, "5MinuteGraphResultCount has been reset to %d due to request being larger than data retention configured with 5MinuteHours.", cfg.fivegresultcount);
+		printe(PT_Config);
+	}
 }
 
 void defaultcfg(void)
@@ -289,6 +323,7 @@ void defaultcfg(void)
 	cfg.unitmode = UNITMODE;
 	cfg.rateunitmode = RATEUNITMODE;
 	cfg.ostyle = OSTYLE;
+	cfg.estimatebarvisible = ESTIMATEBARVISIBLE;
 	cfg.rateunit = RATEUNIT;
 	cfg.defaultdecimals = DEFAULTDECIMALS;
 	cfg.hourlydecimals = HOURLYDECIMALS;
@@ -347,6 +382,14 @@ void defaultcfg(void)
 	cfg.dbsynchronous = DBSYNCHRONOUS;
 
 	cfg.transbg = TRANSBG;
+	cfg.largefonts = LARGEFONTS;
+	cfg.linespaceadjust = LINESPACEADJUST;
+	cfg.imagescale = IMAGESCALE;
+	cfg.fivegresultcount = FIVEGRESULTCOUNT;
+	cfg.fivegheight = FIVEGHEIGHT;
+	cfg.summarygraph = SUMMARYGRAPH;
+	cfg.estimatestyle = ESTIMATESTYLE;
+	cfg.barshowsrate = BARSHOWSRATE;
 	strncpy_nt(cfg.cbg, CBACKGROUND, 8);
 	strncpy_nt(cfg.cedge, CEDGE, 8);
 	strncpy_nt(cfg.cheader, CHEADER, 8);
@@ -359,6 +402,8 @@ void defaultcfg(void)
 	strncpy_nt(cfg.crxd, CRXD, 8);
 	strncpy_nt(cfg.ctx, CTX, 8);
 	strncpy_nt(cfg.ctxd, CTXD, 8);
+
+	cfg.experimental = 0;
 }
 
 int opencfgfile(const char *cfgfile, FILE **fd)
