@@ -253,6 +253,7 @@ void initdstate(DSTATE *s)
 	s->forcesave = 0;
 	s->noadd = 0;
 	s->alwaysadd = 0;
+	s->initdb = 0;
 	s->iflisthash = 0;
 	s->cfgfile[0] = '\0';
 	s->user[0] = '\0';
@@ -513,7 +514,7 @@ int processifinfo(DSTATE *s, datacache **dc)
 
 	if ((*dc)->updated > ifinfo.timestamp) {
 		/* skip update if previous update is less than a day in the future */
-		/* otherwise exit with error message since the clock is problably messed */
+		/* otherwise exit with error message since the clock is probably messed */
 		if ((*dc)->updated > (ifinfo.timestamp + 86400)) {
 			snprintf(errorstring, 1024, "Interface \"%s\" has previous update date too much in the future, exiting. (%u / %u)", (*dc)->interface, (unsigned int)(*dc)->updated, (unsigned int)ifinfo.timestamp);
 			printe(PT_Error);
@@ -552,7 +553,7 @@ int processifinfo(DSTATE *s, datacache **dc)
 
 			/* calculate maximum possible transfer since last update based on set maximum rate */
 			/* and add 2% in order to be on the safe side */
-			maxtransfer = (uint64_t)(ceilf((maxbw / (float)8) * interval * (float)1.02)) * 1024 * 1024;
+			maxtransfer = (uint64_t)(ceilf(((float)maxbw / (float)8) * (float)interval * (float)1.02)) * 1024 * 1024;
 
 			if (debug)
 				printf("interval: %" PRIu64 "  maxbw: %" PRIu32 "  maxrate: %" PRIu64 "  rxc: %" PRIu64 "  txc: %" PRIu64 "\n", (uint64_t)interval, maxbw, maxtransfer, rxchange, txchange);
