@@ -15,7 +15,7 @@ void showdb(const char *interface, int qmode, const char *databegin, const char
 		return;
 	}
 
-	if (info.rxtotal == 0 && info.txtotal == 0) {
+	if (info.created == info.updated) {
 		printf(" %s: Not enough data available yet.\n", interface);
 		return;
 	}
@@ -148,8 +148,8 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 				if (datalist_i->rx == 0 || datalist_i->tx == 0 || (interface->updated - datalist_i->timestamp) == 0) {
 					e_rx = e_tx = 0;
 				} else {
-					e_rx = (uint64_t)(datalist_i->rx / (float)(mosecs(datalist_i->timestamp, interface->updated))) * (uint64_t)(dmonth(d->tm_mon) * 86400);
-					e_tx = (uint64_t)(datalist_i->tx / (float)(mosecs(datalist_i->timestamp, interface->updated))) * (uint64_t)(dmonth(d->tm_mon) * 86400);
+					e_rx = (uint64_t)((double)datalist_i->rx / (double)(mosecs(datalist_i->timestamp, interface->updated))) * (uint64_t)(dmonth(d->tm_mon) * 86400);
+					e_tx = (uint64_t)((double)datalist_i->tx / (double)(mosecs(datalist_i->timestamp, interface->updated))) * (uint64_t)(dmonth(d->tm_mon) * 86400);
 				}
 				if (shortmode && cfg.ostyle != 0) {
 					printf("%s%s", fieldseparator, getvalue(e_rx + e_tx, 11, RT_Estimate));
@@ -236,8 +236,8 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 				if (datalist_i->rx == 0 || datalist_i->tx == 0 || (d->tm_hour * 60 + d->tm_min) == 0) {
 					e_rx = e_tx = 0;
 				} else {
-					e_rx = (uint64_t)((datalist_i->rx) / (float)(d->tm_hour * 60 + d->tm_min)) * 1440;
-					e_tx = (uint64_t)((datalist_i->tx) / (float)(d->tm_hour * 60 + d->tm_min)) * 1440;
+					e_rx = (uint64_t)((double)datalist_i->rx / (double)(d->tm_hour * 60 + d->tm_min)) * 1440;
+					e_tx = (uint64_t)((double)datalist_i->tx / (double)(d->tm_hour * 60 + d->tm_min)) * 1440;
 				}
 				if (shortmode && cfg.ostyle != 0) {
 					printf("%s%s", fieldseparator, getvalue(e_rx + e_tx, 11, RT_Estimate));
@@ -281,11 +281,12 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 	int32_t limit;
 	ListType listtype = LT_None;
 	int offset = 0, i = 1;
+	int estimatevisible = 0;
 	struct tm *d;
 	time_t current;
 	char datebuff[DATEBUFFLEN], daybuff[DATEBUFFLEN];
 	char titlename[16], colname[8], stampformat[64];
-	uint64_t e_rx, e_tx, e_secs, div, mult;
+	uint64_t e_rx = 0, e_tx = 0, e_secs = 0;
 	dbdatalist *datalist = NULL, *datalist_i = NULL;
 	dbdatalistinfo datainfo;
 
@@ -338,11 +339,21 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 
 	daybuff[0] = '\0';
 
-	if (!db_getdata_range(&datalist, &datainfo, interface->name, listname, (uint32_t)limit, databegin, dataend)) {
+	if (!db_getdata_range(&datalist, &datainfo, interface->name, listname, (uint32_t)limit, databegin, dataend) || !datalist) {
 		printf("Error: Failed to fetch %s data.\n", titlename);
 		return;
 	}
 
+	datalist_i = datalist;
+
+	if (strlen(dataend) == 0 && datainfo.count > 0 && (listtype == LT_Day || listtype == LT_Month || listtype == LT_Year)) {
+		estimatevisible = 1;
+		getestimates(&e_rx, &e_tx, listtype, interface->updated, &datalist);
+		if (cfg.estimatebarvisible && e_rx + e_tx > datainfo.max) {
+			datainfo.max = e_rx + e_tx;
+		}
+	}
+
 	if (listtype == LT_Top) {
 		if (limit > 0 && datainfo.count < (uint32_t)limit) {
 			limit = (int32_t)datainfo.count;
@@ -412,8 +423,6 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 		printf("\n");
 	}
 
-	datalist_i = datalist;
-
 	while (datalist_i != NULL) {
 		d = localtime(&datalist_i->timestamp);
 
@@ -452,34 +461,10 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 		printf(" | %s", getvalue(datalist_i->tx, 11, RT_Normal));
 		printf(" | %s", getvalue(datalist_i->rx + datalist_i->tx, 11, RT_Normal));
 		if (cfg.ostyle == 3) {
-			e_secs = 0;
 			if (datalist_i->next == NULL && issametimeslot(listtype, datalist_i->timestamp, interface->updated)) {
-				d = localtime(&interface->updated);
-				if (listtype == LT_Day) {
-					e_secs = (uint64_t)(d->tm_sec + (d->tm_min * 60) + (d->tm_hour * 3600));
-				} else if (listtype == LT_Month) {
-					e_secs = (uint64_t)mosecs(datalist_i->timestamp, interface->updated);
-				} else if (listtype == LT_Year) {
-					e_secs = (uint64_t)(d->tm_yday * 86400 + d->tm_sec + (d->tm_min * 60) + (d->tm_hour * 3600));
-				} else if (listtype == LT_Top) {
-					e_secs = 86400;
-				} else if (listtype == LT_Hour) {
-					e_secs = (uint64_t)(d->tm_sec + (d->tm_min * 60));
-				} else if (listtype == LT_5min) {
-					e_secs = (uint64_t)(d->tm_sec + (d->tm_min % 5 * 60));
-				}
+				e_secs = getperiodseconds(listtype, datalist_i->timestamp, interface->updated, 1);
 			} else {
-				if (listtype == LT_Day || listtype == LT_Top) {
-					e_secs = 86400;
-				} else if (listtype == LT_Month) {
-					e_secs = (uint64_t)(dmonth(d->tm_mon) * 86400);
-				} else if (listtype == LT_Year) {
-					e_secs = (uint64_t)((365 + isleapyear(d->tm_year + 1900)) * 86400);
-				} else if (listtype == LT_Hour) {
-					e_secs = 3600;
-				} else if (listtype == LT_5min) {
-					e_secs = 300;
-				}
+				e_secs = getperiodseconds(listtype, datalist_i->timestamp, interface->updated, 0);
 			}
 			printf(" | %s", gettrafficrate(datalist_i->rx + datalist_i->tx, (time_t)e_secs, 14));
 		} else if (cfg.ostyle != 0) {
@@ -519,31 +504,11 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 		}
 		printf("\n");
 	}
-	if ((strlen(dataend) == 0 && datainfo.count > 0 && (listtype == LT_Day || listtype == LT_Month || listtype == LT_Year)) || (strlen(dataend) > 0 && datainfo.count > 1 && listtype != LT_Top)) {
-		/* use database update time for estimates */
-		d = localtime(&interface->updated);
-		if (datalist_i->rx == 0 || datalist_i->tx == 0 || strlen(dataend) > 0) {
-			e_rx = e_tx = 0;
-		} else {
-			div = 0;
-			mult = 0;
-			if (listtype == LT_Day) {
-				div = (uint64_t)(d->tm_hour * 60 + d->tm_min);
-				mult = 1440;
-			} else if (listtype == LT_Month) {
-				div = (uint64_t)mosecs(datalist_i->timestamp, interface->updated);
-				mult = (uint64_t)(dmonth(d->tm_mon) * 86400);
-			} else if (listtype == LT_Year) {
-				div = (uint64_t)(d->tm_yday * 1440 + d->tm_hour * 60 + d->tm_min);
-				mult = (uint64_t)(1440 * (365 + isleapyear(d->tm_year + 1900)));
-			}
-			if (div > 0) {
-				e_rx = (uint64_t)((datalist_i->rx) / (float)div) * mult;
-				e_tx = (uint64_t)((datalist_i->tx) / (float)div) * mult;
-			} else {
-				e_rx = e_tx = 0;
-			}
-		}
+
+	/* estimate or sum visible */
+	if ( (estimatevisible) ||
+	     (strlen(dataend) > 0 && datainfo.count > 1 && listtype != LT_Top) ) {
+
 		if (cfg.ostyle == 3) {
 			printf("    ");
 		}
@@ -563,9 +528,12 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 		}
 		if (cfg.ostyle == 3) {
 			printf(" |");
+		} else if (cfg.ostyle != 0 && estimatevisible && cfg.estimatebarvisible) {
+			showbar(e_rx, e_tx, datainfo.max, 24 - offset);
 		}
 		printf("\n");
 	}
+
 	dbdatalistfree(&datalist);
 	timeused_debug(__func__, 0);
 }
@@ -676,7 +644,7 @@ void showhours(const interfaceinfo *interface)
 	int i, s = 0, hour, minute, declen = cfg.hourlydecimals, div = 1;
 	unsigned int j, k, tmax = 0, dots = 0;
 	uint64_t max = 1;
-	char matrix[24][81]; /* width is one over 80 so that snprintf can write the end char */
+	char matrix[HGLINES][81]; /* width is one over 80 so that snprintf can write the end char */
 	char unit[4];
 	struct tm *d;
 	dbdatalist *datalist = NULL, *datalist_i = NULL;
@@ -734,14 +702,14 @@ void showhours(const interfaceinfo *interface)
 	}
 
 	/* mr. proper */
-	for (i = 0; i < 24; i++) {
+	for (i = 0; i < HGLINES; i++) {
 		for (j = 0; j < 81; j++) {
 			matrix[i][j] = ' ';
 		}
 	}
 
 	/* unit selection */
-	while (max / (pow(1024, div)) >= 100 && div < UNITPREFIXCOUNT) {
+	while ((double)max / (pow(1024, div)) >= 100 && div < UNITPREFIXCOUNT) {
 		div++;
 	}
 	strncpy_nt(unit, getunitprefix(div), 4);
@@ -785,47 +753,33 @@ void showhours(const interfaceinfo *interface)
 
 		snprintf(matrix[12] + k, 81 - k, "%02d ", s);
 
-		dots = (unsigned int)(10 * (hourdata[s].rx / (float)max));
+		dots = (unsigned int)(10 * ((double)hourdata[s].rx / (double)max));
 		for (j = 0; j < dots; j++)
 			matrix[10 - j][k] = cfg.rxhourchar[0];
 
-		dots = (unsigned int)(10 * (hourdata[s].tx / (float)max));
+		dots = (unsigned int)(10 * ((double)hourdata[s].tx / (double)max));
 		for (j = 0; j < dots; j++)
 			matrix[10 - j][k + 1] = cfg.txhourchar[0];
 
 		k = k + 3;
 	}
 
-	/* hours and traffic */
-	for (i = 0; i <= 7; i++) {
-		s = (int)tmax + i + 1;
-		for (j = 0; j < 3; j++) {
-			snprintf(matrix[15 + i] + (j * 28), 25, "%02d %" DECCONV "10.*f %" DECCONV "10.*f",
-					 ((unsigned int)s + (j * 8)) % 24, declen, hourdata[((unsigned int)s + (j * 8)) % 24].rx / (double)div,
-					 declen, hourdata[((unsigned int)s + (j * 8)) % 24].tx / (double)div);
-		}
-	}
-
 	/* section separators */
-	if (cfg.hourlystyle) {
-		for (i = 0; i < 9; i++) {
-			if (cfg.hourlystyle == 1) {
-				matrix[14 + i][26] = '|';
-				matrix[14 + i][54] = '|';
-			} else if (cfg.hourlystyle == 2) {
-				matrix[14 + i][25] = ']';
-				matrix[14 + i][26] = '[';
-				matrix[14 + i][53] = ']';
-				matrix[14 + i][54] = '[';
-			} else if (cfg.hourlystyle == 3) {
-				matrix[14 + i][26] = '[';
-				matrix[14 + i][53] = ']';
-			}
-		}
+	if (cfg.hourlystyle == 1) {
+		matrix[14][26] = '|';
+		matrix[14][54] = '|';
+	} else if (cfg.hourlystyle == 2) {
+		matrix[14][25] = ']';
+		matrix[14][26] = '[';
+		matrix[14][53] = ']';
+		matrix[14][54] = '[';
+	} else if (cfg.hourlystyle == 3) {
+		matrix[14][26] = '[';
+		matrix[14][53] = ']';
 	}
 
 	/* clean \0 */
-	for (i = 0; i < 23; i++) {
+	for (i = 0; i < HGLINES; i++) {
 		for (j = 0; j < 80; j++) {
 			if (matrix[i][j] == '\0') {
 				matrix[i][j] = ' ';
@@ -833,13 +787,41 @@ void showhours(const interfaceinfo *interface)
 		}
 	}
 
-	/* show matrix (yes, the last line isn't shown) */
-	for (i = 0; i < 23; i++) {
+	/* show matrix */
+	for (i = 0; i < HGLINES; i++) {
 		for (j = 0; j < 80; j++) {
 			printf("%c", matrix[i][j]);
 		}
 		printf("\n");
 	}
+
+	/* hours and traffic */
+	for (i = 0; i <= 7; i++) {
+		s = (int)tmax + i + 1;
+		for (j = 0; j < 3; j++) {
+			printf("%02d %" DECCONV "10.*f %" DECCONV "10.*f", ((unsigned int)s + (j * 8)) % 24,
+					 declen, (double)hourdata[((unsigned int)s + (j * 8)) % 24].rx / (double)div,
+					 declen, (double)hourdata[((unsigned int)s + (j * 8)) % 24].tx / (double)div);
+
+			if (j < 2) {
+				if (cfg.hourlystyle == 1) {
+					printf("  | ");
+				} else if (cfg.hourlystyle == 2) {
+					printf(" ][ ");
+				} else if (cfg.hourlystyle == 3) {
+					if (j == 0) {
+						printf("  [ ");
+					} else {
+						printf(" ]  ");
+					}
+				} else {
+					printf("    ");
+				}
+			}
+		}
+		printf("\n");
+	}
+
 	timeused_debug(__func__, 0);
 }
 
@@ -848,7 +830,7 @@ int showbar(const uint64_t rx, const uint64_t tx, const uint64_t max, const int
 	int i, l, width = len;
 
 	if ((rx + tx) < max) {
-		width = (int)(((rx + tx) / (float)max) * len);
+		width = (int)(((double)(rx + tx) / (double)max) * len);
 	} else if ((rx + tx) > max || max == 0) {
 		return 0;
 	}
@@ -860,7 +842,7 @@ int showbar(const uint64_t rx, const uint64_t tx, const uint64_t max, const int
 	printf("  ");
 
 	if (tx > rx) {
-		l = (int)(rintf((rx / (float)(rx + tx) * width)));
+		l = (int)lrint(((double)rx / (double)(rx + tx) * width));
 
 		for (i = 0; i < l; i++) {
 			printf("%c", cfg.rxchar[0]);
@@ -869,7 +851,7 @@ int showbar(const uint64_t rx, const uint64_t tx, const uint64_t max, const int
 			printf("%c", cfg.txchar[0]);
 		}
 	} else {
-		l = (int)(rintf((tx / (float)(rx + tx) * width)));
+		l = (int)lrint(((double)tx / (double)(rx + tx) * width));
 
 		for (i = 0; i < (width - l); i++) {
 			printf("%c", cfg.rxchar[0]);
