@@ -303,6 +303,7 @@ int db_exec(const char *sql)
 int db_create(void)
 {
 	int i;
+	const char *constsql;
 	char *sql;
 	char buffer[32];
 	const char *datatables[] = {"fiveminute", "hour", "day", "month", "year", "top"};
@@ -311,17 +312,17 @@ int db_create(void)
 		return 0;
 	}
 
-	sql = "CREATE TABLE info(\n"
+	constsql = "CREATE TABLE info(\n"
 		  "  id       INTEGER PRIMARY KEY,\n"
 		  "  name     TEXT UNIQUE NOT NULL,\n"
 		  "  value    TEXT NOT NULL)";
 
-	if (!db_exec(sql)) {
+	if (!db_exec(constsql)) {
 		db_rollbacktransaction();
 		return 0;
 	}
 
-	sql = "CREATE TABLE interface(\n"
+	constsql = "CREATE TABLE interface(\n"
 		  "  id           INTEGER PRIMARY KEY,\n"
 		  "  name         TEXT UNIQUE NOT NULL,\n"
 		  "  alias        TEXT,\n"
@@ -333,7 +334,7 @@ int db_create(void)
 		  "  rxtotal      INTEGER NOT NULL,\n"
 		  "  txtotal      INTEGER NOT NULL)";
 
-	if (!db_exec(sql)) {
+	if (!db_exec(constsql)) {
 		db_rollbacktransaction();
 		return 0;
 	}
@@ -723,16 +724,16 @@ int db_getiflist(iflist **ifl)
 int db_getiflist_sorted(iflist **ifl, const int orderbytraffic)
 {
 	int rc;
-	char *sql;
+	const char *constsql;
 	sqlite3_stmt *sqlstmt;
 
 	if (!orderbytraffic) {
-		sql = "select name from interface order by name asc";
+		constsql = "select name from interface order by name asc";
 	} else {
-		sql = "select name from interface order by rxtotal+txtotal desc";
+		constsql = "select name from interface order by rxtotal+txtotal desc";
 	}
 
-	rc = sqlite3_prepare_v2(db, sql, -1, &sqlstmt, NULL);
+	rc = sqlite3_prepare_v2(db, constsql, -1, &sqlstmt, NULL);
 	if (rc != SQLITE_OK) {
 		db_errcode = rc;
 		snprintf(errorstring, 1024, "Failed to get interface list from database (%d): %s", rc, sqlite3_errmsg(db));
@@ -1378,6 +1379,10 @@ char *getifaceinquery(const char *input)
 	/* each interface requires two quotes and comma or \0 so 3 extra chars */
 	j = (unsigned int)strlen(input) + ifacecount * 3;
 	result = malloc(sizeof(char) * j);
+	if (result == NULL) {
+		panicexit(__FILE__, __LINE__);
+	}
+
 	memset(result, '\0', j);
 
 	result[0] = '"';
