@@ -2,6 +2,7 @@
 #include "vnstat_tests.h"
 #include "misc_tests.h"
 #include "misc.h"
+#include "dbsql.h"
 
 START_TEST(getbtime_does_not_return_zero)
 {
@@ -618,7 +619,7 @@ START_TEST(issametimeslot_knows_its_slots)
 	entry = (time_t)get_timestamp(2019, 4, 15, 12, 30);
 
 	/* the database has the entry timestamp stored with the first possible */
-	/* time of the specific range resulting in many the following scenarios */
+	/* time of the specific range resulting in many of the following scenarios */
 	/* never happening during normal usage */
 
 	updated = (time_t)get_timestamp(2019, 4, 15, 12, 32);
@@ -705,6 +706,193 @@ START_TEST(issametimeslot_knows_its_slots)
 }
 END_TEST
 
+START_TEST(getperiodseconds_knows_fixed_not_ongoing_periods)
+{
+	time_t entry, updated;
+
+	entry = (time_t)get_timestamp(2021, 1, 1, 18, 0);
+	updated = entry;
+
+	ck_assert_int_eq(getperiodseconds(LT_None, entry, updated, 0), 0);
+	ck_assert_int_eq(getperiodseconds(LT_5min, entry, updated, 0), 300);
+	ck_assert_int_eq(getperiodseconds(LT_Hour, entry, updated, 0), 3600);
+	ck_assert_int_eq(getperiodseconds(LT_Day, entry, updated, 0), 86400);
+	ck_assert_int_eq(getperiodseconds(LT_Top, entry, updated, 0), 86400);
+}
+END_TEST
+
+START_TEST(getperiodseconds_knows_dynamic_not_ongoing_periods)
+{
+	time_t entry, updated;
+
+	entry = (time_t)get_timestamp(2021, 1, 1, 18, 0);
+	updated = entry;
+
+	ck_assert_int_eq(getperiodseconds(LT_Month, entry, updated, 0), 2678400);
+
+	/* 2021 isn't a leap year */
+	ck_assert_int_eq(getperiodseconds(LT_Year, entry, updated, 0), 31536000);
+
+	entry = (time_t)get_timestamp(2020, 1, 1, 18, 0);
+	updated = entry;
+
+	/* 2020 is a leap year */
+	ck_assert_int_eq(getperiodseconds(LT_Year, entry, updated, 0), 31622400);
+}
+END_TEST
+
+START_TEST(getperiodseconds_returns_zero_when_there_is_no_time_spent)
+{
+	time_t entry, updated;
+
+	cfg.monthrotate = 1;
+	entry = (time_t)get_timestamp(2021, 1, 1, 0, 0);
+	updated = entry;
+
+	ck_assert_int_eq(getperiodseconds(LT_None, entry, updated, 1), 0);
+	ck_assert_int_eq(getperiodseconds(LT_5min, entry, updated, 1), 0);
+	ck_assert_int_eq(getperiodseconds(LT_Hour, entry, updated, 1), 0);
+	ck_assert_int_eq(getperiodseconds(LT_Day, entry, updated, 1), 0);
+	ck_assert_int_eq(getperiodseconds(LT_Year, entry, updated, 1), 0);
+
+	/* months are special due to cfg.monthrotate */
+	ck_assert_int_eq(getperiodseconds(LT_Month, entry, updated, 1), 1);
+
+	/* LT_Top always returns the same value */
+	ck_assert_int_eq(getperiodseconds(LT_Top, entry, updated, 1), 86400);
+}
+END_TEST
+
+START_TEST(getperiodseconds_knows_spent_ongoing_time)
+{
+	time_t entry, updated;
+
+	cfg.monthrotate = 1;
+	entry = (time_t)get_timestamp(2021, 1, 2, 3, 46);
+	updated = entry;
+
+	ck_assert_int_eq(getperiodseconds(LT_None, entry, updated, 1), 0);
+	ck_assert_int_eq(getperiodseconds(LT_5min, entry, updated, 1), 60);
+	ck_assert_int_eq(getperiodseconds(LT_Hour, entry, updated, 1), 2760);
+	ck_assert_int_eq(getperiodseconds(LT_Day, entry, updated, 1), 13560);
+	ck_assert_int_eq(getperiodseconds(LT_Year, entry, updated, 1), 99960);
+
+	/* months are special due to cfg.monthrotate */
+	ck_assert_int_eq(getperiodseconds(LT_Month, entry, updated, 1), 1);
+
+	/* LT_Top always returns the same value */
+	ck_assert_int_eq(getperiodseconds(LT_Top, entry, updated, 1), 86400);
+}
+END_TEST
+
+START_TEST(getestimates_has_error_handling)
+{
+	time_t updated;
+	uint64_t rx = 1, tx = 2;
+	dbdatalist *datalist = NULL;
+
+	updated = (time_t)get_timestamp(2021, 1, 2, 3, 46);
+
+	getestimates(&rx, &tx, LT_None, updated, &datalist);
+	ck_assert_int_eq(rx, 0);
+	ck_assert_int_eq(tx, 0);
+
+	rx = 1;
+	tx = 2;
+	ck_assert_int_eq(dbdatalistadd(&datalist, 0, 0, 0, 1), 1);
+	getestimates(&rx, &tx, LT_Day, updated, &datalist);
+	ck_assert_int_eq(rx, 0);
+	ck_assert_int_eq(tx, 0);
+	dbdatalistfree(&datalist);
+
+	rx = 1;
+	tx = 2;
+	ck_assert_int_eq(dbdatalistadd(&datalist, 1000000, 0, 0, 1), 1);
+	getestimates(&rx, &tx, LT_Day, updated, &datalist);
+	ck_assert_int_eq(rx, 0);
+	ck_assert_int_eq(tx, 0);
+	dbdatalistfree(&datalist);
+
+	rx = 1;
+	tx = 2;
+	ck_assert_int_eq(dbdatalistadd(&datalist, 0, 1000000, 0, 1), 1);
+	getestimates(&rx, &tx, LT_Day, updated, &datalist);
+	ck_assert_int_eq(rx, 0);
+	ck_assert_int_eq(tx, 0);
+	dbdatalistfree(&datalist);
+
+	rx = 1;
+	tx = 2;
+	ck_assert_int_eq(dbdatalistadd(&datalist, 1000000, 1000000, 0, 1), 1);
+	getestimates(&rx, &tx, LT_None, updated, &datalist);
+	ck_assert_int_eq(rx, 0);
+	ck_assert_int_eq(tx, 0);
+	dbdatalistfree(&datalist);
+}
+END_TEST
+
+START_TEST(getestimates_has_a_crystal_ball)
+{
+	time_t updated;
+	uint64_t rx = 1, tx = 2;
+	dbdatalist *datalist = NULL;
+
+	cfg.monthrotate = 1;
+	updated = (time_t)get_timestamp(2021, 1, 1, 3, 45);
+	ck_assert_int_eq(dbdatalistadd(&datalist, 100000, 200000, updated, 1), 1);
+
+	rx = 1;
+	tx = 2;
+	/* on the 5 minute so there's no calculation done */
+	getestimates(&rx, &tx, LT_5min, updated, &datalist);
+	ck_assert_int_eq(rx, 100000);
+	ck_assert_int_eq(tx, 200000);
+
+	updated = (time_t)get_timestamp(2021, 1, 1, 3, 46);
+
+	rx = 1;
+	tx = 2;
+	getestimates(&rx, &tx, LT_5min, updated, &datalist);
+	ck_assert_int_eq(rx, 499800);
+	ck_assert_int_eq(tx, 999900);
+
+	rx = 1;
+	tx = 2;
+	getestimates(&rx, &tx, LT_Hour, updated, &datalist);
+	ck_assert_int_eq(rx, 129600);
+	ck_assert_int_eq(tx, 259200);
+
+	updated = (time_t)get_timestamp(2021, 1, 2, 3, 0);
+
+	rx = 1;
+	tx = 2;
+	/* on the hour so there's no calculation done */
+	getestimates(&rx, &tx, LT_Hour, updated, &datalist);
+	ck_assert_int_eq(rx, 100000);
+	ck_assert_int_eq(tx, 200000);
+
+	rx = 1;
+	tx = 2;
+	getestimates(&rx, &tx, LT_Day, updated, &datalist);
+	ck_assert_int_eq(rx, 777600);
+	ck_assert_int_eq(tx, 1555200);
+
+	rx = 1;
+	tx = 2;
+	getestimates(&rx, &tx, LT_Month, updated, &datalist);
+	ck_assert_int_eq(rx, 2678400);
+	ck_assert_int_eq(tx, 5356800);
+
+	rx = 1;
+	tx = 2;
+	getestimates(&rx, &tx, LT_Year, updated, &datalist);
+	ck_assert_int_eq(rx, 32061600);
+	ck_assert_int_eq(tx, 64648800);
+
+	dbdatalistfree(&datalist);
+}
+END_TEST
+
 void add_misc_tests(Suite *s)
 {
 	TCase *tc_misc = tcase_create("Misc");
@@ -736,5 +924,11 @@ void add_misc_tests(Suite *s)
 	tcase_add_test(tc_misc, issametimeslot_handles_updates_before_the_entry_time);
 	tcase_add_test(tc_misc, issametimeslot_knows_simple_slots);
 	tcase_add_test(tc_misc, issametimeslot_knows_its_slots);
+	tcase_add_test(tc_misc, getperiodseconds_knows_fixed_not_ongoing_periods);
+	tcase_add_test(tc_misc, getperiodseconds_knows_dynamic_not_ongoing_periods);
+	tcase_add_test(tc_misc, getperiodseconds_returns_zero_when_there_is_no_time_spent);
+	tcase_add_test(tc_misc, getperiodseconds_knows_spent_ongoing_time);
+	tcase_add_test(tc_misc, getestimates_has_error_handling);
+	tcase_add_test(tc_misc, getestimates_has_a_crystal_ball);
 	suite_add_tcase(s, tc_misc);
 }
